==> unicore-ucc6-5.0.0-1.src.tar.gz: ucc-core/src/main/java/de/fzj/unicore/ucc/actions/PutFile.java <==
package de.fzj.unicore.ucc.actions;

import org.apache.commons.cli.OptionBuilder;
import org.unigrids.services.atomic.types.ProtocolType;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

import de.fzj.unicore.uas.client.StorageClient;
import de.fzj.unicore.ucc.helpers.Location;
import de.fzj.unicore.ucc.util.FileUploader;
import de.fzj.unicore.ucc.util.Mode;
import de.fzj.unicore.wsrflite.xmlbeans.WSUtilities;

/**
 * get a file from a remote sms
 */
public class PutFile extends FileOperation {

	protected Location targetDesc;
	protected StorageClient sms;
	protected boolean recurse;
	protected boolean append;

	@Override
	@SuppressWarnings("all")
	protected void createOptions() {
		super.createOptions();
		getOptions().addOption(OptionBuilder.withLongOpt(OPT_APPEND_LONG)
				.withDescription("Append to (existing) file")
				.isRequired(false)
				.create(OPT_APPEND)
		);
		getOptions().addOption(OptionBuilder.withLongOpt(OPT_RECURSIVE_LONG)
				.withDescription("Recurse into subdirectories")
				.isRequired(false)
				.create(OPT_RECURSIVE)
		);
	}

	@Override
	public void process() {
		super.process();
		targetDesc=new Location(target,registry,securityProperties,this);
		verbose("Target URL "+targetDesc.getUnicore6URI());
		append=getBooleanOption(OPT_APPEND_LONG, OPT_APPEND);
		verbose("Appending data="+append);
		recurse=getBooleanOption(OPT_RECURSIVE_LONG, OPT_RECURSIVE);
		if(recurse)verbose("Recurse into subdirectories="+recurse);
		try{
			EndpointReferenceType e=EndpointReferenceType.Factory.newInstance();
			e.addNewAddress().setStringValue(targetDesc.getSmsEpr());
			String dn=findServerName(e);
			if(dn!=null)WSUtilities.addServerIdentity(e, dn);
			sms=new StorageClient(targetDesc.getSmsEpr(),e,securityProperties);
			verbose("SMS contacted, server reply: servertime="+sms.getCurrentTime());
			putFile();
		}catch(Exception e){
			error("Can't put file.",e);
			endProcessing(ERROR);
		}
	}

	protected void putFile()throws Exception{
		Mode mode=append?Mode.append:Mode.overwrite;
		FileUploader imp=new FileUploader(source,targetDesc.getName(),mode);
		String targetDescProtocol=targetDesc.getProtocol();
		if(!"BFT".equalsIgnoreCase(targetDescProtocol)){
			try{
				preferredProtocols.add(0, ProtocolType.Enum.forString(targetDescProtocol));
			}catch(Exception ignored){}
		}
		imp.setPreferredProtocols(preferredProtocols);
		imp.setExtraParameterSource(properties);
		imp.setTiming(timing);
		imp.setRecurse(recurse);
		imp.perform(sms, this);
	}

	@Override
	public String getName() {
		return "put-file";
	}

	@Override
	public String getSynopsis() {
		return "Writes a local file specified by the '-s' option to a remote location '-t'.";
	}
	@Override
	public String getDescription(){
		return "puts a local file to a remote server";
	}

	@Override
	public String getArgumentList(){
		return "";
	}
	@Override
	public String getCommandGroup(){
		return "Data management";
	}
}

==> unicore-ucc6-6.0.0-0.src.tar.gz: ucc-core/src/main/java/de/fzj/unicore/ucc/actions/PutFile.java <==
package de.fzj.unicore.ucc.actions;

import org.apache.commons.cli.OptionBuilder;
import org.unigrids.services.atomic.types.ProtocolType;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

import de.fzj.unicore.uas.client.StorageClient;
import de.fzj.unicore.ucc.helpers.Location;
import de.fzj.unicore.ucc.util.FileUploader;
import de.fzj.unicore.ucc.util.Mode;
import de.fzj.unicore.wsrflite.xmlbeans.WSUtilities;

/**
 * get a file from a remote sms
 */
public class PutFile extends FileOperation {

	protected Location targetDesc;
	protected StorageClient sms;
	protected boolean recurse;
	protected boolean append;

	@Override
	@SuppressWarnings("all")
	protected void createOptions() {
		super.createOptions();
		getOptions().addOption(OptionBuilder.withLongOpt(OPT_APPEND_LONG)
				.withDescription("Append to (existing) file")
				.isRequired(false)
				.create(OPT_APPEND)
		);
		getOptions().addOption(OptionBuilder.withLongOpt(OPT_RECURSIVE_LONG)
				.withDescription("Recurse into subdirectories")
				.isRequired(false)
				.create(OPT_RECURSIVE)
		);
	}

	@Override
	public void process() {
		super.process();
		targetDesc=new Location(target,registry,securityProperties,this);
		verbose("Target URL "+targetDesc.getUnicore6URI());
		append=getBooleanOption(OPT_APPEND_LONG, OPT_APPEND);
		verbose("Appending data="+append);
		recurse=getBooleanOption(OPT_RECURSIVE_LONG, OPT_RECURSIVE);
		if(recurse)verbose("Recurse into subdirectories="+recurse);
		try{
			EndpointReferenceType e=EndpointReferenceType.Factory.newInstance();
			e.addNewAddress().setStringValue(targetDesc.getSmsEpr());
			String dn=findServerName(e);
			if(dn!=null)WSUtilities.addServerIdentity(e, dn);
			sms=new StorageClient(targetDesc.getSmsEpr(),e,securityProperties);
			verbose("SMS contacted, server reply: servertime="+sms.getCurrentTime());
			putFile();
		}catch(Exception e){
			error("Can't put file.",e);
			endProcessing(ERROR);
		}
	}

	protected void putFile()throws Exception{
		Mode mode=append?Mode.append:Mode.overwrite;
		FileUploader imp=new FileUploader(source,targetDesc.getName(),mode);
		String targetDescProtocol=targetDesc.getProtocol();
		if(!"BFT".equalsIgnoreCase(targetDescProtocol)){
			try{
				preferredProtocols.add(0, ProtocolType.Enum.forString(targetDescProtocol));
			}catch(Exception ignored){}
		}
		imp.setPreferredProtocols(preferredProtocols);
		imp.setExtraParameterSource(properties);
		imp.setTiming(timing);
		imp.setRecurse(recurse);
		if(startByte!=null){
			imp.setStartByte(startByte);
			imp.setEndByte(endByte);
		}
		imp.perform(sms, this);
	}

	@Override
	public String getName() {
		return "put-file";
	}

	@Override
	public String getSynopsis() {
		return "Writes a local file specified by the '-s' option to a remote location '-t'.";
	}
	@Override
	public String getDescription(){
		return "put a local file to a remote server";
	}

	@Override
	public String getArgumentList(){
		return "";
	}
	@Override
	public String getCommandGroup(){
		return "Data management";
	}
}
